summary refs log tree commit diff
path: root/src/dns
diff options
context:
space:
mode:
Diffstat (limited to 'src/dns')
-rw-r--r--src/dns/nm-dns-manager.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/dns/nm-dns-manager.c b/src/dns/nm-dns-manager.c
index 973abc1c..dc545470 100644
--- a/src/dns/nm-dns-manager.c
+++ b/src/dns/nm-dns-manager.c
@@ -1448,11 +1448,13 @@ nm_dns_manager_stop (NMDnsManager *self)
 	_LOGT ("stopping...");
 
 	/* If we're quitting, leave a valid resolv.conf in place, not one
 	 * pointing to 127.0.0.1 if any plugins were active.  Thus update
 	 * DNS after disposing of all plugins.  But if we haven't done any
 	 * DNS updates yet, there's no reason to touch resolv.conf on shutdown.
 	 */
-	if (priv->dns_touched) {
+	if (   priv->dns_touched
+	    && priv->plugin
+	    && NM_IS_DNS_DNSMASQ (priv->plugin)) {
 		if (!update_dns (self, TRUE, &error)) {
 			_LOGW ("could not commit DNS changes on shutdown: %s", error->message);
 			g_clear_error (&error);
@@ -1448,11 +1448,13 @@ nm_dns_manager_stop (NMDnsManager *self)
 
 	/* If we're quitting, leave a valid resolv.conf in place, not one
-	 * pointing to 127.0.0.1 if any plugins were active.  Thus update
-	 * DNS after disposing of all plugins.  But if we haven't done any
-	 * DNS updates yet, there's no reason to touch resolv.conf on shutdown.
+	 * pointing to 127.0.0.1 if dnsmasq was active.  But if we haven't
+	 * done any DNS updates yet, there's no reason to touch resolv.conf
+	 * on shutdown.
 	 */